@@ -7,7 +7,7 @@ use warnings;
 use JSON;
 use Slack::RTM::Bot::Client;
 
-our $VERSION = "0.09";
+our $VERSION = "0.10";
 
 pipe(READH, WRITEH);
 select(WRITEH);$|=1;
@@ -128,7 +128,7 @@ Slack::RTM::Bot - This is a perl module helping to create slack bot with Real Ti
 
     $bot->on({
             channel => 'general',
-            text    => /.*/
+            text    => qr/.*/
         },
         sub {
             my ($response) = @_;
@@ -143,10 +143,12 @@ Slack::RTM::Bot - This is a perl module helping to create slack bot with Real Ti
         text    => '<!here> hello, world.'
     );
 
-    $bot->say({
+    $bot->say(
         channel => '@username',
         text    => 'hello, world.'
-    });
+    );
+
+    while(1) { sleep 10; print "I'm not dead\n"; }
 
 =head1 METHODS
 
